GuestPtr

Struct GuestPtr 

pub struct GuestPtr<T: ?Sized + Pointee> { /* private fields */ }

Implementations

Source

impl<T: ?Sized + Pointee> GuestPtr<T>

pub fn new(pointer: T::Pointer) -> Self

pub fn offset(&self) -> T::Pointer

pub fn cast<U>(&self) -> GuestPtr<U>
where U: Pointee<Pointer = T::Pointer> + ?Sized,

Casts this GuestPtr type to a different type.

This is a safe method which is useful for simply reinterpreting the type parameter on this GuestPtr. Note that this is a safe method, where again there’s no guarantees about alignment, validity, in-bounds-ness, etc of the returned pointer.

pub fn add(&self, amt: u32) -> Result<GuestPtr<T>, GuestError>
where T: GuestType + Pointee<Pointer = u32>,

Performs pointer arithmetic on this pointer, moving the pointer forward amt slots.

This will either return the resulting pointer or Err if the pointer arithmetic calculation would overflow around the end of the address space.

pub fn as_array(&self, elems: u32) -> GuestPtr<[T]>
where T: GuestType + Pointee<Pointer = u32>,

Returns a GuestPtr for an array of Ts using this pointer as the base.

Source

impl<T> GuestPtr<[T]>

pub fn offset_base(&self) -> u32

pub fn len(&self) -> u32

pub fn iter( &self, ) -> impl ExactSizeIterator<Item = Result<GuestPtr<T>, GuestError>> + '_
where T: GuestType,

pub fn as_ptr(&self) -> GuestPtr<T>

Source

impl GuestPtr<str>

pub fn as_bytes(&self) -> GuestPtr<[u8]>